@@ -6,7 +6,7 @@
 ;; Maintainer: Modus-Themes Development <~protesilaos/modus-themes@lists.sr.ht>
 ;; URL: https://git.sr.ht/~protesilaos/modus-themes
 ;; Mailing-List: https://lists.sr.ht/~protesilaos/modus-themes
-;; Version: 2.5.0
+;; Version: 3.0.0
 ;; Package-Requires: ((emacs "27.1"))
 ;; Keywords: faces, theme, accessibility
 
@@ -71,4 +71,7 @@ which corresponds to a minimum contrast in relative luminance of
 
   (provide-theme 'modus-operandi))
 
+;;;###theme-autoload
+(put 'modus-operandi 'theme-properties '(:background-mode light :kind color-scheme :family modus))
+
 ;;; modus-operandi-theme.el ends here
